================
 Citing HyperSpy
================

If HyperSpy has been significant to a project that leads to an academic
publication, please acknowledge that fact by citing it. The DOI in the
badge below is the `Concept DOI <https://help.zenodo.org/#versioning>`_ of
HyperSpy. It can be used to cite the project without referring to a specific
version. If you are citing HyperSpy because you have used it to process data,
please use the DOI of the specific version that you have employed. You can
find iy by clicking on the DOI badge below.

.. image:: https://zenodo.org/badge/doi/10.5281/zenodo.592838.svg
   :target: https://doi.org/10.5281/zenodo.592838
